clear Q refs limits

refs.x=2;   % just weight state #2
Q.x=1;
Q.rho=Inf;  % hard constraints
%Q.norm=2;   % Quadratic costs
Q.norm=Inf; % Infinity norm costs
N=2;

limits.xmin=[25;-Inf];

C=hybcon(S,Q,N,limits,refs);
C.mipsolver='glpk';   % used for MILP
%C.mipsolver='cplex';  % used for MIQP

Tstop=100;
x0=[30;30]; % initial state
r.x=30+15*sin((0:199)'/5);

[XX,UU,DD,ZZ,TT]=sim(C,S,r,x0,Tstop);
subplot(311);
plot(TT,XX(:,2),TT,r.x);
grid
title('Temperature T_2')
subplot(312);
plot(TT,XX(:,1),TT,10*ZZ(:,2));
grid
title('Temperature T_1, air conditioning')
subplot(313);
plot(TT,UU);
grid
title('Temperature T_{amb}')

break

h=msgbox('Now simulate the closed-loop system in Simulink');
waitfor(h);
close(gcf)

open_system('bm99mld');
sim('bm99mld',Tstop);

h=msgbox('Now convert the MLD system to PWA and simulate it again');
waitfor(h);
close_system('bm99mld');

P=pwa(S);
open_system('bm99pwa');
sim('bm99pwa',Tstop);

h=questdlg('Compute the explicit form of the hybrid controller ?','No','Yes');
close_system('bm99pwa');

if strcmp(h,'No'),
    return
end

clear range options
range.xmin=[-10;-10];    % Set of initial states where the mp-problem is solved
range.xmax=[10;10];    
range.refymin=-1;        % Set of ouput references where the mp-problem is solved
range.refymax=1;     

options.verbose=0;
options.lpsolver='glpk'; %   uses GLPKMEX.DLL 
options.uniteeps=1e-6;   
options.flattol=1e-4;
options.waitbar=1;
E=expcon(C,range,options);
plotsection(E,3,0);

Tstop=100;
P=pwa(S);
x0=[0;0];

h=msgbox('Now simulate closed-loop system with explicit controller');
waitfor(h);
close(gcf);

open_system('bm99exp');
sim('bm99exp',Tstop);